<?php
// +--------------------------------------------------------------------------+
// | PayPal Plugin - geeklog CMS                                             |
// +--------------------------------------------------------------------------+
// | product_edit.php                                                         |
// |                                                                          |
// | Displays a form for the editing products                                 |
// |                                                                          |
// | Allows for the altering and deletion of existing products as well as the |
// | creation of new products                                                 |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | Copyright (C) 2005-2006 by the following authors:                        |
// |                                                                          |
// | Authors: Vincent Furia     - vinny01 AT users DOT sourceforge DOT net    |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | This program is free software; you can redistribute it and/or            |
// | modify it under the terms of the GNU General Public License              |
// | as published by the Free Software Foundation; either version 2           |
// | of the License, or (at your option) any later version.                   |
// |                                                                          |
// | This program is distributed in the hope that it will be useful,          |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of           |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            |
// | GNU General Public License for more details.                             |
// |                                                                          |
// | You should have received a copy of the GNU General Public License        |
// | along with this program; if not, write to the Free Software Foundation,  |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.          |
// |                                                                          |
// +--------------------------------------------------------------------------+

/**
 * Displays a form for the editing products
 *
 * Allows for the altering and deletion of existing products as well as the
 * creation of new products
 *
 * @author Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
 * @copyright Vincent Furia 2005 - 2006
 * @package paypal
 */

/**
 * Required geeklog
 */
require_once('../../../lib-common.php');

// Check for required permissions
paypal_access_check('paypal.admin');

// Incoming variable filter
$vars = array('op' => 'alpha',
              'id' => 'number',
              'name' => 'text',
              'category' => 'text',
              'short_description' => 'text',
              'description' => 'html',
              'price' => 'alpha',
			  'logged' => 'number',
              'download' => 'number',
              'physical' => 'number',
              'file' => 'alpha',
              'expiration' => 'number' );
paypal_filterVars($vars, $_REQUEST);

/**
 * This function creates a product Form
 *
 * Creates a Form for a product using the supplied defaults (if specified).
 *
 * @param array $product array of values describing a proudct
 * @return string HTML string of product form
 */
function getProductForm($product = array()) {

    global $_CONF, $_PAY_CONF, $LANG_PAYPAL_1, $_TABLES, $LANG24, $LANG_ADMIN;

    $display = COM_startBlock($LANG_PAYPAL_1['edit_label'] . ' ' . $product['name']);

    $template = new Template($_CONF['path'] . 'plugins/paypal/templates');
    $template->set_file(array('product' => 'product_form.thtml'));
    $template->set_var('site_url', $_CONF['site_url']);
    $template->set_var('name_label', $LANG_PAYPAL_1['name_label']);
    $template->set_var('category_label', $LANG_PAYPAL_1['category_label']);
	$template->set_var('short_description_label', $LANG_PAYPAL_1['short_description_label']);
	$template->set_var('description_label', $LANG_PAYPAL_1['description_label']);
	$template->set_var('price_label', $LANG_PAYPAL_1['price_label']);

	//images
	$template->set_var('lang_images', $LANG24[47]);
	$fileinputs = '';
    $saved_images = '';
    if ($_PAY_CONF['max_images_per_products'] > 0) {
        $icount = DB_count($_TABLES['paypal_images'],'pi_pid', $product['id']);
        if ($icount > 0) {
            $result_products = DB_query("SELECT * FROM {$_TABLES['paypal_images']} WHERE pi_pid = '". $product['id'] ."'");
            for ($z = 1; $z <= $icount; $z++) {
                $I = DB_fetchArray($result_products);
                $saved_images .= '<div><p>' . $z . ') '
					. '<a class="lightbox" href="' . $_PAY_CONF['site_url'] . '/images/products/' . $I['pi_filename'] . '"><img align="top" class="lightbox" src="'. $_PAY_CONF['site_url'] . '/timthumb.php?src='. $_PAY_CONF['site_url'] . '/images/products/' . $I['pi_filename'] . '&amp;w=75&amp;h=75&amp;zc=1&amp;q=100" alt="' . $I['pi_filename'] . '" /></a>'
                    . '&nbsp;&nbsp;&nbsp;' . $LANG_ADMIN['delete']
                    . ': <input type="checkbox" name="delete[' .$I['pi_img_num']
                    . ']"' . XHTML . '><br' . XHTML . '></p></div>';
            }
        }

        $newallowed = $_PAY_CONF['max_images_per_products'] - $icount;
        for ($z = $icount + 1; $z <= $_PAY_CONF['max_images_per_products']; $z++) {
            $fileinputs .= $z . ') <input type="file" dir="ltr" name="file'
                        . $z . '"' . XHTML . '> ';
            if ($z < $_PAY_CONF['max_images_per_products']) {
                $fileinputs .= '<br' . XHTML . '>';
            }
        }
    }
    $template->set_var('saved_images', $saved_images);
    $template->set_var('image_form_elements', $fileinputs);
	
	$template->set_var('logged_to_purchase', $LANG_PAYPAL_1['logged_to_purchase']);
	
	$template->set_var('downloaded_product_label', $LANG_PAYPAL_1['downloaded_product_label']);
	$template->set_var('yes', $LANG_PAYPAL_1['yes']);
	$template->set_var('no', $LANG_PAYPAL_1['no']);
	$template->set_var('shipped_product_label', $LANG_PAYPAL_1['shipped_product_label']);
	$template->set_var('filename_label', $LANG_PAYPAL_1['filename_label']);
	$template->set_var('expiration_label', $LANG_PAYPAL_1['expiration_label']);
	$template->set_var('save_button', $LANG_PAYPAL_1['save_button']);
	$template->set_var('delete_button', $LANG_PAYPAL_1['delete_button']);
	$template->set_var('ok_button', $LANG_PAYPAL_1['ok_button']);
	$template->set_var('required_field', $LANG_PAYPAL_1['required_field']);
	$template->set_var('currency', $_PAY_CONF['currency']);

    if (is_numeric($product['id'])) {
        $template->set_var('id', '<input type="hidden" name="id" value="' . $product['id'] .'" />');
    } else {
        $template->set_var('id', '');
    }
    $template->set_var('name', $product['name']);
    $template->set_var('category', $product['category']);
	$categories_list = "SELECT category, count(*) count FROM {$_TABLES['paypal_products']} WHERE category IS NOT NULL AND category <> '' GROUP BY category ORDER BY category";
    $res = DB_query($categories_list);
    $nrows = DB_numRows($res);
	if ($nrows > 0) {
	    $categories = $LANG_PAYPAL_1['existing_categories'];  
	    for ($i = 1; $i <= $nrows; $i++) {
    	    $C = DB_fetchArray ($res);
    	    $categories .=  ' <strong>' . $C['category'] . '</strong> | ';
		}
	}
	$template->set_var('categories', $categories);
    $template->set_var('short_description',
                       strip_tags($product['short_description']));
    $template->set_var('description', $product['description']);
    $template->set_var('price', $product['price']);

    if ($product['logged'] == 1) {
        $template->set_var('logged_yes', ' selected');
        $template->set_var('logged_no', '');
    } else {
        $template->set_var('logged_yes', '');
        $template->set_var('logged_no', ' selected');
    }
	if ($product['download'] == 1) {
        $template->set_var('download_yes', ' selected');
        $template->set_var('download_no', '');
    } else {
        $template->set_var('download_yes', '');
        $template->set_var('download_no', ' selected');
    }
    if ($product['physical'] == 1) {
        $template->set_var('physical_yes', ' selected');
        $template->set_var('physical_no', '');
    } else {
        $template->set_var('physical_yes', '');
        $template->set_var('physical_no', ' selected');
    }
    $template->set_var('file', $product['file']);
    $template->set_var('expiration', $product['expiration']);
    $display .= $template->parse('output', 'product');

    $display .= COM_endBlock();
    return $display;
}

function saveImage ($product, $_FILES, $pid) {
    global $_CONF, $_PAY_CONF, $_TABLES, $LANG24;
	
    $args = &$product;

    // Handle Magic GPC Garbage:
    while (list($key, $value) = each($args)) {
        if (!is_array($value)) {
            $args[$key] = COM_stripslashes($value);
        } else {
            while (list($subkey, $subvalue) = each($value)) {
                $value[$subkey] = COM_stripslashes($subvalue);
            }
        }
    }

	// Delete any images if needed
	if (array_key_exists('delete', $args)) {
		$delete = count($args['delete']);
		for ($i = 1; $i <= $delete; $i++) {
			$pi_filename = DB_getItem ($_TABLES['paypal_images'],'pi_filename', 'pi_pid = ' . $pid . ' AND pi_img_num = ' . key($args['delete']));
			PAYPAL_deleteImage ($pi_filename);
			DB_query ("DELETE FROM {$_TABLES['paypal_images']} WHERE pi_pid = ". $pid . " AND pi_img_num = " . key($args['delete']));
			next($args['delete']);
		}
	}

	// OK, let's upload any pictures with the product
	if (DB_count($_TABLES['paypal_images'], 'pi_pid', $pid) > 0) {
		$index_start = DB_getItem($_TABLES['paypal_images'],'max(pi_img_num)',"pi_pid = '". $pid. "'") + 1;
	} else {
		$index_start = 1;
	}

	if (count($_FILES) > 0 AND $_PAY_CONF['max_images_per_products'] > 0) {
		require_once($_CONF['path_system'] . 'classes/upload.class.php');
		$upload = new upload();

		//Debug with story debug function
		if (isset ($_CONF['debug_image_upload']) && $_CONF['debug_image_upload']) {
			$upload->setLogFile ($_CONF['path'] . 'logs/error.log');
			$upload->setDebug (true);
		}
		$upload->setMaxFileUploads ($_PAY_CONF['max_images_per_products']);
		if (!empty($_CONF['image_lib'])) {
			if ($_CONF['image_lib'] == 'imagemagick') {
				// Using imagemagick
				$upload->setMogrifyPath ($_CONF['path_to_mogrify']);
			} elseif ($_CONF['image_lib'] == 'netpbm') {
				// using netPBM
				$upload->setNetPBM ($_CONF['path_to_netpbm']);
			} elseif ($_CONF['image_lib'] == 'gdlib') {
				// using the GD library
				$upload->setGDLib ();
			}
			$upload->setAutomaticResize(false);
			$upload->keepOriginalImage (true);

			if (isset($_CONF['jpeg_quality'])) {
				$upload->setJpegQuality($_CONF['jpeg_quality']);
			}
		}
		$upload->setAllowedMimeTypes (array (
				'image/gif'   => '.gif',
				'image/jpeg'  => '.jpg,.jpeg',
				'image/pjpeg' => '.jpg,.jpeg',
				'image/x-png' => '.png',
				'image/png'   => '.png'
				));
		
		if (!$upload->setPath($_PAY_CONF['path_html'] . 'images/products/')) {
			$output = COM_siteHeader ('menu', $LANG24[30]);
			$output .= COM_startBlock ($LANG24[30], '', COM_getBlockTemplate ('_msg_block', 'header'));
			$output .= $upload->printErrors (false);
			$output .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
			$output .= COM_siteFooter ();
			echo $output;
			exit;
		}

		// NOTE: if $_CONF['path_to_mogrify'] is set, the call below will
		// force any images bigger than the passed dimensions to be resized.
		// If mogrify is not set, any images larger than these dimensions
		// will get validation errors
		$upload->setMaxDimensions($_PAY_CONF['max_image_width'], $_PAY_CONF['max_image_height']);
		$upload->setMaxFileSize($_PAY_CONF['max_image_size']); // size in bytes, 1048576 = 1MB

		// Set file permissions on file after it gets uploaded (number is in octal)
		$upload->setPerms('0644');
		$filenames = array();
		$end_index = $index_start + $upload->numFiles() - 1;
		for ($z = $index_start; $z <= $end_index; $z++) {
			$curfile = current($_FILES);
			if (!empty($curfile['name'])) {
				$pos = strrpos($curfile['name'],'.') + 1;
				$fextension = substr($curfile['name'], $pos);
				$filenames[] = $pid . '_' . $z . '.' . $fextension;
			}
			next($_FILES);
		}
		$upload->setFileNames($filenames);
		reset($_FILES);
		$upload->uploadFiles();

		if ($upload->areErrors()) {
			$retval = COM_siteHeader('menu', $LANG24[30]);
			$retval .= COM_startBlock ($LANG24[30], '',
						COM_getBlockTemplate ('_msg_block', 'header'));
			$retval .= $upload->printErrors(false);
			$retval .= COM_endBlock(COM_getBlockTemplate ('_msg_block', 'footer'));
			$retval .= COM_siteFooter();
			echo $retval;
			exit;
		}

		reset($filenames);
		for ($z = $index_start; $z <= $end_index; $z++) {
			DB_query("INSERT INTO {$_TABLES['paypal_images']} (pi_pid, pi_img_num, pi_filename) VALUES ('" . $pid . "', $z, '" . current($filenames) . "')");
			next($filenames);
		}
	}
	return true;
}

/**
* Delete one image from a product
*
* @param    string  $image  file name of the image (without the path)
*
*/
function PAYPAL_deleteImage ($image)
{
    global $_PAY_CONF;

    if (empty ($image)) {
        return;
    }
	
	$pi_url = $_PAY_CONF['path_html'] . 'images/products/' . $image;
			if (!@unlink ($pi_url)) {
                // log the problem but don't abort the script
                echo COM_errorLog ('Unable to remove the following image from the product: ' . $image);
            }
    // Todo remove image from cache
}

/**
 * main section
 */
switch ($_REQUEST['op']) {
    case 'delete':
	    DB_delete($_TABLES['paypal_products'], 'id', $_REQUEST['id']);
    if (DB_affectedRows('') == 1) {
        $msg = $LANG_PAYPAL_1['deletion_succes'];
    } else {
        $msg = $LANG_PAYPAL_1['deletion_fail'];
    }
		// delete complete, return to product list
        echo COM_refresh($_CONF['site_url'] . "/admin/plugins/paypal/index.php?msg=$msg");
        exit();
        break;

    case 'save':
        if (empty($_REQUEST['name']) || empty($_REQUEST['short_description']) ||
                !is_numeric($_REQUEST['price']) || !is_numeric($_REQUEST['download']) ) {
            $display = COM_startBlock($LANG_PAYPAL_1['error']);
            $display .= $LANG_PAYPAL_1['missing_field'];
            $display .= COM_endBlock();
            $display .= getProductForm($_REQUEST);
            break;
        }

        // prepare strings for insertion
        $_REQUEST['name'] = addslashes($_REQUEST['name']);
        $_REQUEST['category'] = addslashes($_REQUEST['category']);
        $_REQUEST['short_description'] = addslashes($_REQUEST['short_description']);
        $_REQUEST['description'] = addslashes($_REQUEST['description']);

        // price can only contain numbers and a decimal
        $_REQUEST['price'] = preg_replace('/[^\d.]/', '', $_REQUEST['price']);

        // 0 indicates no expiraton and must be stored as NULL in the DB
        if ( $_REQUEST['expiration'] == 0 ) {
            $_REQUEST['expiration'] = 'NULL';
        }
        $sql = "name = '{$_REQUEST['name']}', "
        		 . "category = '{$_REQUEST['category']}', "
             . "short_description = '{$_REQUEST['short_description']}', "
             . "description = '{$_REQUEST['description']}', "
             . "price = {$_REQUEST['price']}, "
             . "download = {$_REQUEST['download']}, "
             //. "physical = {$_REQUEST['physical']}, "
			 . "logged = {$_REQUEST['logged']}, "
             . "file = '{$_REQUEST['file']}', "
             . "expiration = {$_REQUEST['expiration']}";
        if (!empty($_REQUEST['id'])) {
            $sql = "UPDATE {$_TABLES['paypal_products']} SET $sql "
                 . "WHERE id = {$_REQUEST['id']}";
        } else {
            $sql = "INSERT INTO {$_TABLES['paypal_products']} SET $sql ";
        }
        DB_query($sql);
        if (DB_error()) {
            $msg = $LANG_PAYPAL_1['save_fail'];
        } else {
            $msg = $LANG_PAYPAL_1['save_success'];
        }
		
		//Process images
		
		if (empty($_REQUEST['id'])) {
	        $last_pid = DB_insertId();
	    } else {
		    $last_pid = $_REQUEST['id'];
		}
		saveImage ($_REQUEST, $_FILES, $last_pid);
		
        // save complete, return to product list
        echo COM_refresh($_CONF['site_url'] . "/admin/plugins/paypal/index.php?msg=$msg");
        exit();
        break;

    /* this case is currently not used... future expansion? */
    case 'preview':
        $display = getProductForm($_REQUEST);
        break;

    case 'edit':
        // Get the product to edit and display the form
        if (is_numeric($_REQUEST['id'])) {
            $sql = "SELECT * FROM {$_TABLES['paypal_products']} WHERE id = {$_REQUEST['id']}";
            $res = DB_query($sql);
            $A = DB_fetchArray($res);
            $display = getProductForm($A);
        } else {
            echo COM_refresh($_CONF['site_url']);
        }
        break;

    case 'new':
    default:
        $display = getProductForm($A = '');
        break;
}

$display = COM_siteHeader() . paypal_admin_menu() . $display;
$display .= COM_siteFooter();

COM_output($display);

?>