<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | paypal plugin 1.1                                                         |
// +---------------------------------------------------------------------------+
// | install_defaults.php                                                      |
// |                                                                           |
// | Initial Installation Defaults used when loading the online configuration  |
// | records. These settings are only used during the initial installation     |
// | and not referenced any more once the plugin is installed.                 |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2010 by the following authors:                              |
// |                                                                           |
// | Authors: Ben        - cordiste AT free DOT fr                             |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

if (strpos(strtolower($_SERVER['PHP_SELF']), 'install_defaults.php') !== false) {
    die('This file can not be used on its own!');
}

/*
 * paypal default settings
 *
 * Initial Installation Defaults used when loading the online configuration
 * records. These settings are only used during the initial installation
 * and not referenced any more once the plugin is installed
 *
 */
 
/**
*   Default values to be used during plugin installation/upgrade
*   @global array $_PAY_DEFAULT
*/
global $_DB_table_prefix, $_PAY_DEFAULT, $LANG_PAY_1;

$_PAY_DEFAULT = array();

$_PAY_DEFAULT['pi_name']    = 'paypal'; // Plugin name

/**
*   Main settings
*/
$_PAY_DEFAULT['paypal_folder']    = 'paypal'; //Allow to move the directory where the users's paypal program is store
$_PAY_DEFAULT['menulabel']    = 'Shop';
$_PAY_DEFAULT['paypal_login_required'] = 1;

// Set to 1 to hide the "paypal" entry from the top menu:
$_PAY_DEFAULT['hide_paypal_menu'] = 0;

// Set the default permissions
$_PAY_DEFAULT['default_permissions'] =  array (3, 3, 2, 2);

/**
*   Display Settings
*/
/**
 * URL for paypal verification should be www.paypal.com for live service
 * or www.sandbox.paypal.com for testing.
 * If your version of PHP is 4.3.0 or greater and OpenSSL has been compiled
 * into PHP, you can prefix the url below with "ssl://" to encrypt the
 * paypal 'postback'.
 */
$_PAY_DEFAULT['paypalURL'] = 'www.sandbox.paypal.com';

/**
 * PayPal email addresses for your business receiver account,
 */
$_PAY_DEFAULT['receiverEmailAddr'] = '';

/**
 * This is the currency that you want all transactions to occur in.  Your
 * Paypal account must have the choosen currency enabled (on the Paypal website
 * see: Selling Preferences->Paypment Receiving Preferences).  This plugin
 * currently requires you to have only one currency balance enabled in your
 * Paypal account. 
 */
 $_PAY_DEFAULT['currency'] = 'EUR';

/**
 * 1 to allow anonymous users to make purchases without logging in first.  Note
 * that anonymous users won't have access to purchase history or to direct downloads
 */
$_PAY_DEFAULT['anonymous_buy'] = 1;

/**
 * Configuration parameters to specify whether "on purchase" emails will be sent.
 * Be sure to edit the files templates/purchase_email_subject.txt and
 *  templates/purchase_email_message.txt to customize the email message.
 * You should disable the *_attach options below if you are distributing large files
 *  or it is likely that a purchaser will be buying many medium files otherwise the
 *  email will become too large and will likely never be received
 * purchase_email_user true if logged in users should get a purchase email
 * purchase_email_user_attach true if logged in users should get purchases
 *                            emailed as attachments
 * purchase_email_anon true if anonymous users should get a purchase email
 * purchase_email_anon_attach true if anonymous users should get purchases
 *                            emailed as attachments
 */
$_PAY_DEFAULT['purchase_email_user']        = true;
$_PAY_DEFAULT['purchase_email_user_attach'] = true;
$_PAY_DEFAULT['purchase_email_anon']        = true;
$_PAY_DEFAULT['purchase_email_anon_attach'] = true;

/**
 * Number of products to display per page.  0 indicates that all products should
 * be displayed on a single page.
 */
$_PAY_DEFAULT['maxPerPage'] = 10;

/**
 * Number of columns of categories to display.  Set to 0 to disable categories.
 * If you don't have any categories set, this setting is meaningless.
 */
 $_PAY_DEFAULT['categoryColumns'] = 3;
 
 /**
 * Images settings
 */
 $_PAY_DEFAULT['max_images_per_products'] = 5;
 $_PAY_DEFAULT['max_image_width'] = 1600;
 $_PAY_DEFAULT['max_image_height'] = 1600;
 $_PAY_DEFAULT['max_image_size'] = 1048576;
 $_PAY_DEFAULT['max_thumbnail_size'] = 75;

/**
* Initialize paypal plugin configuration
*
* Creates the database entries for the configuation if they don't already
* exist. 
*
* @return   boolean     true: success; false: an error occurred
*
*/
function plugin_initconfig_paypal()
{
    global $_CONF, $_PAY_DEFAULT;
	
    $c = config::get_instance();
    if (!$c->group_exists('paypal')) {

        //This is main subgroup #0
		$c->add('sg_main', NULL, 'subgroup', 0, 0, NULL, 0, true, 'paypal');
		
		//Main settings   
		$c->add('fs_main', NULL, 'fieldset', 0, 0, NULL, 0, true, 'paypal');
        $c->add('paypal_folder', $_PAY_DEFAULT['paypal_folder'],
                'text', 0, 0, 0, 1, true, 'paypal');
		$c->add('menulabel', $_PAY_DEFAULT['menulabel'],
                'text', 0, 0, 0, 2, true, 'paypal');
		$c->add('paypal_login_required', $_PAY_DEFAULT['paypal_login_required'],
                'select', 0, 0, 3, 12, true, 'paypal');
		$c->add('hide_paypal_menu', $_PAY_DEFAULT['hide_paypal_menu'],
                'select', 0, 0, 3, 13, true, 'paypal');
		$c->add('paypalURL', $_PAY_DEFAULT['paypalURL'],
                'text', 0, 0, 0, 23, true, 'paypal');
		$c->add('receiverEmailAddr', $_PAY_DEFAULT['receiverEmailAddr'],
                'text', 0, 0, 0, 24, true, 'paypal');
		$c->add('currency', $_PAY_DEFAULT['currency'],
                'select', 0, 0, 20, 33, true, 'paypal');
		$c->add('anonymous_buy', $_PAY_DEFAULT['anonymous_buy'],
                'select', 0, 0, 3, 35, true, 'paypal');
		$c->add('purchase_email_user', $_PAY_DEFAULT['purchase_email_user'],
                'select', 0, 0, 3, 47, true, 'paypal');
		$c->add('purchase_email_user_attach', $_PAY_DEFAULT['purchase_email_user_attach'],
                'select', 0, 0, 3, 49, true, 'paypal');
		$c->add('purchase_email_anon', $_PAY_DEFAULT['purchase_email_anon'],
                'select', 0, 0, 3, 51, true, 'paypal');
		$c->add('purchase_email_anon_attach', $_PAY_DEFAULT['purchase_email_anon_attach'],
                'select', 0, 0, 3, 53, true, 'paypal');
		$c->add('maxPerPage', $_PAY_DEFAULT['maxPerPage'],
                'text', 0, 0, 0, 63, true, 'paypal');
		$c->add('categoryColumns', $_PAY_DEFAULT['categoryColumns'],
                'text', 0, 0, 0, 65, true, 'paypal');

		//images
        $c->add('fs_images', NULL, 'fieldset', 0, 1, NULL, 0, true, 'paypal');
		$c->add('max_images_per_products', $_PAY_DEFAULT['max_images_per_products'],
                'text', 0, 1, 0, 1, true, 'paypal');
		$c->add('max_image_width', $_PAY_DEFAULT['max_image_width'],
                'text', 0, 1, 0, 2, true, 'paypal');
		$c->add('max_image_height', $_PAY_DEFAULT['max_image_height'],
                'text', 0, 1, 0, 3, true, 'paypal');
		$c->add('max_image_size', $_PAY_DEFAULT['max_image_size'],
                'text', 0, 1, 0, 4, true, 'paypal');
		$c->add('max_thumbnail_size', $_PAY_DEFAULT['max_thumbnail_size'],
                'text', 0, 1, 0, 5, true, 'paypal');
		
				
		//This is display subgroup #1
		$c->add('sg_display', NULL, 'subgroup', 1, 0, NULL, 0, true, 'paypal');
		
		// Display settings
		$c->add('fs_display', NULL, 'fieldset', 1, 8, NULL, 0, true, 'paypal');
		$c->add('paypal_main_header', NULL, 'text', 1, 8, 0, 2, true, 'paypal');
		$c->add('paypal_main_footer', NULL, 'text', 1, 8, 0, 4, true, 'paypal');
		
    }				

    return true;
}

?>